/******************************************************************************\
    FILE...........: Automaton.cpp
    AUTHOR.........: Uriah   A. Alshevsky <uriaha@mail.ru>
                     Michael G. Raer      <mraer@mail.ru>
    DESCRIPTON.....: Implements class CAutomaton.
    CLASSES........: CAutomaton
    COPYRIGHT......: (c) 2002 RA_TEAM
    VERSION........: 1.0
    HISTORY........: DATE       COMMENT
                                     ---------- --------------------------------------------------
                                     12-04-2002 Created by Michael Raer

\******************************************************************************/


/*==================================[ IMPORT  DECLARATIONS ]==================*/
#include "StdAfx.h"
#include "String.h"
#include "StdLib.h"
#include "Automaton.h"
#include "x.h"
#include "z.h"

const gMsgNum = 100;

CAutomaton::CAutomaton(const char *aname, char anumber):CLogStr(aname, anumber)
{
	mPrv_cur = new char[gMsgNum];
	mPrv_new = new char[gMsgNum];
	memset((void *)mPrv_new, 0, gMsgNum);
	memset((void *)mPrv_cur, 0, gMsgNum);
	y_new = 0;
	y_cur = 0;
	tNames = 0;
}

CAutomaton::~CAutomaton()
{
	delete [] mPrv_new;
	delete [] mPrv_cur;
	if(stNames) delete []stNames;
}


char CAutomaton::M(int msgNum)
{
	char b;

	b = (mPrv_cur[msgNum] || mPub_cur[msgNum]);
	if (LOGGING && M_LOGGING) MLogging(msgNum, b);
	return b;
}

char CAutomaton::X(int xNum)
{
	char b;
	b = x_arr[xNum]();
	if (LOGGING && X_LOGGING) XLogging(xNum, b);
	return b;
}

void CAutomaton::Z(int zNum)
{
	z_arr[zNum]();
	if (LOGGING && Z_LOGGING) ZLogging(zNum);
}

void CAutomaton::SendPubMsg(CLogStr *a, int msgNum)
{
	if (a->Is_Logging() && a->M_SEND_LOGGING) MSendPubLogging (a, msgNum);
	mPub_new[msgNum] = 1;
}

void CAutomaton::SendPrvMsg(CLogStr *a, int msgNum)
{
	if (a->Is_Logging() && a->M_SEND_LOGGING) MSendPrvLogging (a, msgNum);
	mPrv_new[msgNum] = 1;
}

void CAutomaton::UpdatePubMsg()
{
	memset((void *)mPub_cur, 0, gMsgNum);
	char *tmp;
	tmp = mPub_new;
	mPub_new = mPub_cur;
	mPub_cur = tmp;
}

void CAutomaton::UpdatePrvMsg()
{
	memset((void *)mPrv_cur, 0, gMsgNum);
	char *tmp;
	tmp = mPrv_new;
	mPrv_new = mPrv_cur;
	mPrv_cur = tmp;
}

void CAutomaton::U()
{
	y_cur = y_new;
	UpdatePrvMsg();
}

char tempM1[gMsgNum];
char tempM2[gMsgNum];
char *CAutomaton::mPub_new = tempM1;
char *CAutomaton::mPub_cur = tempM2;

/** (END OF FILE : Automaton.cpp )*************************************************/